@@ -20,7 +20,7 @@ class Api:
         return requests.get(
             self.url + "/api/create_dataset",
             {"token": self.token, "name": name, "description": description},
-        ).text
+        ).text[1:-1]
 
     def list_datasets(self):
         return requests.get(
@@ -49,7 +49,7 @@ class Api:
                 "feedback": feedback,
                 "meta": json.dumps(meta),
             },
-        ).text
+        ).text[1:-1]
 
     def get_data(self, dataset_id: str):
         return requests.get(
